from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BinMDF import *
from OCC.Core.Message import *
from OCC.Core.TDF import *
from OCC.Core.BinObjMgt import *
from OCC.Core.BinTools import *
from OCC.Core.TopLoc import *


class binmxcafdoc:
	@staticmethod
	def AddDrivers(theDriverTable: BinMDF_ADriverTable, theMsgDrv: Message_Messenger) -> None: ...

class BinMXCAFDoc_AssemblyItemRefDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_CentroidDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_ColorDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_DatumDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_DimTolDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_GraphNodeDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_LocationDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...
	def SetSharedLocations(self, theLocations: BinTools_LocationSetPtr) -> None: ...
	@overload
	def Translate(self, theSource: BinObjMgt_Persistent, theLoc: TopLoc_Location, theMap: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Translate(self, theLoc: TopLoc_Location, theTarget: BinObjMgt_Persistent, theMap: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_MaterialDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_NoteDriver(BinMDF_ADriver):
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_VisMaterialDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_VisMaterialToolDriver(BinMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_NoteBinDataDriver(BinMXCAFDoc_NoteDriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMXCAFDoc_NoteCommentDriver(BinMXCAFDoc_NoteDriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

binmxcafdoc_AddDrivers = binmxcafdoc.AddDrivers



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Plate module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_plate.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Plate
else:
    import _Plate

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Plate.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Plate.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Plate.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Plate.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Plate.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Plate.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Plate.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Plate.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Plate.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Plate.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Plate.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Plate.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Plate.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Plate.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Plate.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Plate.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Plate.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Plate:
_Plate.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Plate.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TColgp
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_Plate_HArray1OfPinpointConstraint_Create() -> "opencascade::handle< Plate_HArray1OfPinpointConstraint >":
    return _Plate.Handle_Plate_HArray1OfPinpointConstraint_Create()

def Handle_Plate_HArray1OfPinpointConstraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Plate_HArray1OfPinpointConstraint >":
    return _Plate.Handle_Plate_HArray1OfPinpointConstraint_DownCast(t)

def Handle_Plate_HArray1OfPinpointConstraint_IsNull(t: "opencascade::handle< Plate_HArray1OfPinpointConstraint > const &") -> "bool":
    return _Plate.Handle_Plate_HArray1OfPinpointConstraint_IsNull(t)
class Plate_Array1OfPinpointConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< Plate_PinpointConstraint >::iterator":
        return _Plate.Plate_Array1OfPinpointConstraint_begin(self)

    def end(self) -> "NCollection_Array1< Plate_PinpointConstraint >::iterator":
        return _Plate.Plate_Array1OfPinpointConstraint_end(self)

    def cbegin(self) -> "NCollection_Array1< Plate_PinpointConstraint >::const_iterator":
        return _Plate.Plate_Array1OfPinpointConstraint_cbegin(self)

    def cend(self) -> "NCollection_Array1< Plate_PinpointConstraint >::const_iterator":
        return _Plate.Plate_Array1OfPinpointConstraint_cend(self)

    def __init__(self, *args):
        _Plate.Plate_Array1OfPinpointConstraint_swiginit(self, _Plate.new_Plate_Array1OfPinpointConstraint(*args))

    def Init(self, theValue: "Plate_PinpointConstraint") -> "void":
        return _Plate.Plate_Array1OfPinpointConstraint_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _Plate.Plate_Array1OfPinpointConstraint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Plate.Plate_Array1OfPinpointConstraint_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Plate.Plate_Array1OfPinpointConstraint_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _Plate.Plate_Array1OfPinpointConstraint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Plate.Plate_Array1OfPinpointConstraint_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _Plate.Plate_Array1OfPinpointConstraint_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _Plate.Plate_Array1OfPinpointConstraint_IsAllocated(self)

    def Assign(self, theOther: "Plate_Array1OfPinpointConstraint") -> "NCollection_Array1< Plate_PinpointConstraint > &":
        return _Plate.Plate_Array1OfPinpointConstraint_Assign(self, theOther)

    def Move(self, theOther: "Plate_Array1OfPinpointConstraint") -> "NCollection_Array1< Plate_PinpointConstraint > &":
        return _Plate.Plate_Array1OfPinpointConstraint_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< Plate_PinpointConstraint > &":
        return _Plate.Plate_Array1OfPinpointConstraint_Set(self, *args)

    def First(self) -> "Plate_PinpointConstraint const &":
        return _Plate.Plate_Array1OfPinpointConstraint_First(self)

    def ChangeFirst(self) -> "Plate_PinpointConstraint &":
        return _Plate.Plate_Array1OfPinpointConstraint_ChangeFirst(self)

    def Last(self) -> "Plate_PinpointConstraint const &":
        return _Plate.Plate_Array1OfPinpointConstraint_Last(self)

    def ChangeLast(self) -> "Plate_PinpointConstraint &":
        return _Plate.Plate_Array1OfPinpointConstraint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Plate_PinpointConstraint const &":
        return _Plate.Plate_Array1OfPinpointConstraint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Plate_PinpointConstraint &":
        return _Plate.Plate_Array1OfPinpointConstraint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Plate_PinpointConstraint &":
        return _Plate.Plate_Array1OfPinpointConstraint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Plate_PinpointConstraint") -> "void":
        return _Plate.Plate_Array1OfPinpointConstraint_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _Plate.Plate_Array1OfPinpointConstraint_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _Plate.delete_Plate_Array1OfPinpointConstraint

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register Plate_Array1OfPinpointConstraint in _Plate:
_Plate.Plate_Array1OfPinpointConstraint_swigregister(Plate_Array1OfPinpointConstraint)

class Plate_SequenceOfLinearScalarConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Plate_LinearScalarConstraint >::iterator":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_begin(self)

    def end(self) -> "NCollection_Sequence< Plate_LinearScalarConstraint >::iterator":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_end(self)

    def cbegin(self) -> "NCollection_Sequence< Plate_LinearScalarConstraint >::const_iterator":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Plate_LinearScalarConstraint >::const_iterator":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_cend(self)

    def __init__(self, *args):
        _Plate.Plate_SequenceOfLinearScalarConstraint_swiginit(self, _Plate.new_Plate_SequenceOfLinearScalarConstraint(*args))

    def Size(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Clear(self, theAllocator)

    def Assign(self, theOther: "Plate_SequenceOfLinearScalarConstraint") -> "NCollection_Sequence< Plate_LinearScalarConstraint > &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Assign(self, theOther)

    def Set(self, theOther: "Plate_SequenceOfLinearScalarConstraint") -> "NCollection_Sequence< Plate_LinearScalarConstraint > &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Plate_SequenceOfLinearScalarConstraint") -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Split(self, theIndex, theSeq)

    def First(self) -> "Plate_LinearScalarConstraint const &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_First(self)

    def ChangeFirst(self) -> "Plate_LinearScalarConstraint &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_ChangeFirst(self)

    def Last(self) -> "Plate_LinearScalarConstraint const &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Last(self)

    def ChangeLast(self) -> "Plate_LinearScalarConstraint &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Plate_LinearScalarConstraint const &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Plate_LinearScalarConstraint &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Plate_LinearScalarConstraint &":
        return _Plate.Plate_SequenceOfLinearScalarConstraint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Plate_LinearScalarConstraint") -> "void":
        return _Plate.Plate_SequenceOfLinearScalarConstraint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Plate.delete_Plate_SequenceOfLinearScalarConstraint

    def __len__(self):
        return self.Size()


# Register Plate_SequenceOfLinearScalarConstraint in _Plate:
_Plate.Plate_SequenceOfLinearScalarConstraint_swigregister(Plate_SequenceOfLinearScalarConstraint)

def Plate_SequenceOfLinearScalarConstraint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Plate.Plate_SequenceOfLinearScalarConstraint_delNode(theNode, theAl)

class Plate_SequenceOfLinearXYZConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Plate_LinearXYZConstraint >::iterator":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_begin(self)

    def end(self) -> "NCollection_Sequence< Plate_LinearXYZConstraint >::iterator":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_end(self)

    def cbegin(self) -> "NCollection_Sequence< Plate_LinearXYZConstraint >::const_iterator":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Plate_LinearXYZConstraint >::const_iterator":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_cend(self)

    def __init__(self, *args):
        _Plate.Plate_SequenceOfLinearXYZConstraint_swiginit(self, _Plate.new_Plate_SequenceOfLinearXYZConstraint(*args))

    def Size(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Clear(self, theAllocator)

    def Assign(self, theOther: "Plate_SequenceOfLinearXYZConstraint") -> "NCollection_Sequence< Plate_LinearXYZConstraint > &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Assign(self, theOther)

    def Set(self, theOther: "Plate_SequenceOfLinearXYZConstraint") -> "NCollection_Sequence< Plate_LinearXYZConstraint > &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Plate_SequenceOfLinearXYZConstraint") -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Split(self, theIndex, theSeq)

    def First(self) -> "Plate_LinearXYZConstraint const &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_First(self)

    def ChangeFirst(self) -> "Plate_LinearXYZConstraint &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_ChangeFirst(self)

    def Last(self) -> "Plate_LinearXYZConstraint const &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Last(self)

    def ChangeLast(self) -> "Plate_LinearXYZConstraint &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Plate_LinearXYZConstraint const &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Plate_LinearXYZConstraint &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Plate_LinearXYZConstraint &":
        return _Plate.Plate_SequenceOfLinearXYZConstraint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Plate_LinearXYZConstraint") -> "void":
        return _Plate.Plate_SequenceOfLinearXYZConstraint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Plate.delete_Plate_SequenceOfLinearXYZConstraint

    def __len__(self):
        return self.Size()


# Register Plate_SequenceOfLinearXYZConstraint in _Plate:
_Plate.Plate_SequenceOfLinearXYZConstraint_swigregister(Plate_SequenceOfLinearXYZConstraint)

def Plate_SequenceOfLinearXYZConstraint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Plate.Plate_SequenceOfLinearXYZConstraint_delNode(theNode, theAl)

class Plate_SequenceOfPinpointConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Plate_PinpointConstraint >::iterator":
        return _Plate.Plate_SequenceOfPinpointConstraint_begin(self)

    def end(self) -> "NCollection_Sequence< Plate_PinpointConstraint >::iterator":
        return _Plate.Plate_SequenceOfPinpointConstraint_end(self)

    def cbegin(self) -> "NCollection_Sequence< Plate_PinpointConstraint >::const_iterator":
        return _Plate.Plate_SequenceOfPinpointConstraint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Plate_PinpointConstraint >::const_iterator":
        return _Plate.Plate_SequenceOfPinpointConstraint_cend(self)

    def __init__(self, *args):
        _Plate.Plate_SequenceOfPinpointConstraint_swiginit(self, _Plate.new_Plate_SequenceOfPinpointConstraint(*args))

    def Size(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfPinpointConstraint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfPinpointConstraint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfPinpointConstraint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Plate.Plate_SequenceOfPinpointConstraint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Plate.Plate_SequenceOfPinpointConstraint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Clear(self, theAllocator)

    def Assign(self, theOther: "Plate_SequenceOfPinpointConstraint") -> "NCollection_Sequence< Plate_PinpointConstraint > &":
        return _Plate.Plate_SequenceOfPinpointConstraint_Assign(self, theOther)

    def Set(self, theOther: "Plate_SequenceOfPinpointConstraint") -> "NCollection_Sequence< Plate_PinpointConstraint > &":
        return _Plate.Plate_SequenceOfPinpointConstraint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Plate_SequenceOfPinpointConstraint") -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_Split(self, theIndex, theSeq)

    def First(self) -> "Plate_PinpointConstraint const &":
        return _Plate.Plate_SequenceOfPinpointConstraint_First(self)

    def ChangeFirst(self) -> "Plate_PinpointConstraint &":
        return _Plate.Plate_SequenceOfPinpointConstraint_ChangeFirst(self)

    def Last(self) -> "Plate_PinpointConstraint const &":
        return _Plate.Plate_SequenceOfPinpointConstraint_Last(self)

    def ChangeLast(self) -> "Plate_PinpointConstraint &":
        return _Plate.Plate_SequenceOfPinpointConstraint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Plate_PinpointConstraint const &":
        return _Plate.Plate_SequenceOfPinpointConstraint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Plate_PinpointConstraint &":
        return _Plate.Plate_SequenceOfPinpointConstraint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Plate_PinpointConstraint &":
        return _Plate.Plate_SequenceOfPinpointConstraint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Plate_PinpointConstraint") -> "void":
        return _Plate.Plate_SequenceOfPinpointConstraint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Plate.delete_Plate_SequenceOfPinpointConstraint

    def __len__(self):
        return self.Size()


# Register Plate_SequenceOfPinpointConstraint in _Plate:
_Plate.Plate_SequenceOfPinpointConstraint_swigregister(Plate_SequenceOfPinpointConstraint)

def Plate_SequenceOfPinpointConstraint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Plate.Plate_SequenceOfPinpointConstraint_delNode(theNode, theAl)

class Plate_D1(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        du: gp_XYZ
        dv: gp_XYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        ref: Plate_D1

        Returns
        -------
        None

        """
        _Plate.Plate_D1_swiginit(self, _Plate.new_Plate_D1(*args))

    def DU(self, *args) -> "gp_XYZ const":
        r"""
        No available documentation.

        Returns
        -------
        gp_XYZ

        """
        return _Plate.Plate_D1_DU(self, *args)

    def DV(self, *args) -> "gp_XYZ const":
        r"""
        No available documentation.

        Returns
        -------
        gp_XYZ

        """
        return _Plate.Plate_D1_DV(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_D1

# Register Plate_D1 in _Plate:
_Plate.Plate_D1_swigregister(Plate_D1)

class Plate_D2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        duu: gp_XYZ
        duv: gp_XYZ
        dvv: gp_XYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        ref: Plate_D2

        Returns
        -------
        None

        """
        _Plate.Plate_D2_swiginit(self, _Plate.new_Plate_D2(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_D2

# Register Plate_D2 in _Plate:
_Plate.Plate_D2_swigregister(Plate_D2)

class Plate_D3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        duuu: gp_XYZ
        duuv: gp_XYZ
        duvv: gp_XYZ
        dvvv: gp_XYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        ref: Plate_D3

        Returns
        -------
        None

        """
        _Plate.Plate_D3_swiginit(self, _Plate.new_Plate_D3(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_D3

# Register Plate_D3 in _Plate:
_Plate.Plate_D3_swigregister(Plate_D3)

class Plate_FreeGtoCConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        IncrementalLoad: float,optional
        	default value is 1.0
        orientation: int,optional
        	default value is 0

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        D2S: Plate_D2
        D2T: Plate_D2
        IncrementalLoad: float,optional
        	default value is 1.0
        orientation: int,optional
        	default value is 0

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        D2S: Plate_D2
        D2T: Plate_D2
        D3S: Plate_D3
        D3T: Plate_D3
        IncrementalLoad: float,optional
        	default value is 1.0
        orientation: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        _Plate.Plate_FreeGtoCConstraint_swiginit(self, _Plate.new_Plate_FreeGtoCConstraint(*args))

    def GetPPC(self, *args) -> "Plate_PinpointConstraint const &":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Plate_PinpointConstraint

        """
        return _Plate.Plate_FreeGtoCConstraint_GetPPC(self, *args)

    def LSC(self, *args) -> "Plate_LinearScalarConstraint const &":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Plate_LinearScalarConstraint

        """
        return _Plate.Plate_FreeGtoCConstraint_LSC(self, *args)

    def nb_LSC(self, *args) -> "Standard_Integer const &":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Plate.Plate_FreeGtoCConstraint_nb_LSC(self, *args)

    def nb_PPC(self, *args) -> "Standard_Integer const &":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Plate.Plate_FreeGtoCConstraint_nb_PPC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_FreeGtoCConstraint

# Register Plate_FreeGtoCConstraint in _Plate:
_Plate.Plate_FreeGtoCConstraint_swigregister(Plate_FreeGtoCConstraint)

class Plate_GlobalTranslationConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        SOfXY: TColgp_SequenceOfXY

        Returns
        -------
        None

        """
        _Plate.Plate_GlobalTranslationConstraint_swiginit(self, _Plate.new_Plate_GlobalTranslationConstraint(*args))

    def LXYZC(self, *args) -> "Plate_LinearXYZConstraint const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_LinearXYZConstraint

        """
        return _Plate.Plate_GlobalTranslationConstraint_LXYZC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_GlobalTranslationConstraint

# Register Plate_GlobalTranslationConstraint in _Plate:
_Plate.Plate_GlobalTranslationConstraint_swigregister(Plate_GlobalTranslationConstraint)

class Plate_GtoCConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        ref: Plate_GtoCConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        nP: gp_XYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        D2S: Plate_D2
        D2T: Plate_D2

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        D2S: Plate_D2
        D2T: Plate_D2
        nP: gp_XYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        D2S: Plate_D2
        D2T: Plate_D2
        D3S: Plate_D3
        D3T: Plate_D3

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        D1S: Plate_D1
        D1T: Plate_D1
        D2S: Plate_D2
        D2T: Plate_D2
        D3S: Plate_D3
        D3T: Plate_D3
        nP: gp_XYZ

        Returns
        -------
        None

        """
        _Plate.Plate_GtoCConstraint_swiginit(self, _Plate.new_Plate_GtoCConstraint(*args))

    def D1SurfInit(self, *args) -> "Plate_D1 const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_D1

        """
        return _Plate.Plate_GtoCConstraint_D1SurfInit(self, *args)

    def GetPPC(self, *args) -> "Plate_PinpointConstraint const &":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        Plate_PinpointConstraint

        """
        return _Plate.Plate_GtoCConstraint_GetPPC(self, *args)

    def nb_PPC(self, *args) -> "Standard_Integer const &":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Plate.Plate_GtoCConstraint_nb_PPC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_GtoCConstraint

# Register Plate_GtoCConstraint in _Plate:
_Plate.Plate_GtoCConstraint_swigregister(Plate_GtoCConstraint)

class Plate_LineConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        lin: gp_Lin
        iu: int,optional
        	default value is 0
        iv: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        _Plate.Plate_LineConstraint_swiginit(self, _Plate.new_Plate_LineConstraint(*args))

    def LSC(self, *args) -> "Plate_LinearScalarConstraint const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_LinearScalarConstraint

        """
        return _Plate.Plate_LineConstraint_LSC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_LineConstraint

# Register Plate_LineConstraint in _Plate:
_Plate.Plate_LineConstraint_swigregister(Plate_LineConstraint)

class Plate_LinearScalarConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        thePPC1: Plate_PinpointConstraint
        theCoeff: gp_XYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        thePPC: Plate_Array1OfPinpointConstraint
        theCoeff: TColgp_Array1OfXYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        thePPC: Plate_Array1OfPinpointConstraint
        theCoeff: TColgp_Array2OfXYZ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        ColLen: int
        RowLen: int

        Returns
        -------
        None

        """
        _Plate.Plate_LinearScalarConstraint_swiginit(self, _Plate.new_Plate_LinearScalarConstraint(*args))

    def Coeff(self, *args) -> "TColgp_Array2OfXYZ const &":
        r"""
        No available documentation.

        Returns
        -------
        TColgp_Array2OfXYZ

        """
        return _Plate.Plate_LinearScalarConstraint_Coeff(self, *args)

    def GetPPC(self, *args) -> "Plate_Array1OfPinpointConstraint const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_Array1OfPinpointConstraint

        """
        return _Plate.Plate_LinearScalarConstraint_GetPPC(self, *args)

    def SetCoeff(self, *args) -> "void":
        r"""
        Sets the coeff of index (row,col) to value raise if row (respectively col) is greater than the row (respectively column) length of coeff.

        Parameters
        ----------
        Row: int
        Col: int
        Value: gp_XYZ

        Returns
        -------
        None

        """
        return _Plate.Plate_LinearScalarConstraint_SetCoeff(self, *args)

    def SetPPC(self, *args) -> "void":
        r"""
        Sets the pinpointconstraint of index index to value raise if index is greater than the length of ppc or the row length of coeff or lower than 1.

        Parameters
        ----------
        Index: int
        Value: Plate_PinpointConstraint

        Returns
        -------
        None

        """
        return _Plate.Plate_LinearScalarConstraint_SetPPC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_LinearScalarConstraint

# Register Plate_LinearScalarConstraint in _Plate:
_Plate.Plate_LinearScalarConstraint_swigregister(Plate_LinearScalarConstraint)

class Plate_LinearXYZConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        thePPC: Plate_Array1OfPinpointConstraint
        theCoeff: TColStd_Array1OfReal

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        thePPC: Plate_Array1OfPinpointConstraint
        theCoeff: TColStd_Array2OfReal

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        ColLen: int
        RowLen: int

        Returns
        -------
        None

        """
        _Plate.Plate_LinearXYZConstraint_swiginit(self, _Plate.new_Plate_LinearXYZConstraint(*args))

    def Coeff(self, *args) -> "TColStd_Array2OfReal const &":
        r"""
        No available documentation.

        Returns
        -------
        TColStd_Array2OfReal

        """
        return _Plate.Plate_LinearXYZConstraint_Coeff(self, *args)

    def GetPPC(self, *args) -> "Plate_Array1OfPinpointConstraint const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_Array1OfPinpointConstraint

        """
        return _Plate.Plate_LinearXYZConstraint_GetPPC(self, *args)

    def SetCoeff(self, *args) -> "void":
        r"""
        Sets the coeff of index (row,col) to value raise if row (respectively col) is greater than the row (respectively column) length of coeff.

        Parameters
        ----------
        Row: int
        Col: int
        Value: float

        Returns
        -------
        None

        """
        return _Plate.Plate_LinearXYZConstraint_SetCoeff(self, *args)

    def SetPPC(self, *args) -> "void":
        r"""
        Sets the pinpointconstraint of index index to value raise if index is greater than the length of ppc or the row length of coeff or lower than 1.

        Parameters
        ----------
        Index: int
        Value: Plate_PinpointConstraint

        Returns
        -------
        None

        """
        return _Plate.Plate_LinearXYZConstraint_SetPPC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_LinearXYZConstraint

# Register Plate_LinearXYZConstraint in _Plate:
_Plate.Plate_LinearXYZConstraint_swigregister(Plate_LinearXYZConstraint)

class Plate_PinpointConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        ImposedValue: gp_XYZ
        iu: int,optional
        	default value is 0
        iv: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        _Plate.Plate_PinpointConstraint_swiginit(self, _Plate.new_Plate_PinpointConstraint(*args))

    def Idu(self, *args) -> "Standard_Integer const &":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Plate.Plate_PinpointConstraint_Idu(self, *args)

    def Idv(self, *args) -> "Standard_Integer const &":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Plate.Plate_PinpointConstraint_Idv(self, *args)

    def Pnt2d(self, *args) -> "gp_XY const":
        r"""
        No available documentation.

        Returns
        -------
        gp_XY

        """
        return _Plate.Plate_PinpointConstraint_Pnt2d(self, *args)

    def Value(self, *args) -> "gp_XYZ const":
        r"""
        No available documentation.

        Returns
        -------
        gp_XYZ

        """
        return _Plate.Plate_PinpointConstraint_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_PinpointConstraint

# Register Plate_PinpointConstraint in _Plate:
_Plate.Plate_PinpointConstraint_swigregister(Plate_PinpointConstraint)

class Plate_PlaneConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        pln: gp_Pln
        iu: int,optional
        	default value is 0
        iv: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        _Plate.Plate_PlaneConstraint_swiginit(self, _Plate.new_Plate_PlaneConstraint(*args))

    def LSC(self, *args) -> "Plate_LinearScalarConstraint const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_LinearScalarConstraint

        """
        return _Plate.Plate_PlaneConstraint_LSC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_PlaneConstraint

# Register Plate_PlaneConstraint in _Plate:
_Plate.Plate_PlaneConstraint_swigregister(Plate_PlaneConstraint)

class Plate_Plate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Ref: Plate_Plate

        Returns
        -------
        None

        """
        _Plate.Plate_Plate_swiginit(self, _Plate.new_Plate_Plate(*args))

    def CoefPol(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Coefs: TColgp_HArray2OfXYZ

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_CoefPol(self, *args)

    def Continuity(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _Plate.Plate_Plate_Continuity(self, *args)

    def Copy(self, *args) -> "Plate_Plate &":
        r"""
        No available documentation.

        Parameters
        ----------
        Ref: Plate_Plate

        Returns
        -------
        Plate_Plate

        """
        return _Plate.Plate_Plate_Copy(self, *args)

    def Evaluate(self, *args) -> "gp_XYZ":
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY

        Returns
        -------
        gp_XYZ

        """
        return _Plate.Plate_Plate_Evaluate(self, *args)

    def EvaluateDerivative(self, *args) -> "gp_XYZ":
        r"""
        No available documentation.

        Parameters
        ----------
        point2d: gp_XY
        iu: int
        iv: int

        Returns
        -------
        gp_XYZ

        """
        return _Plate.Plate_Plate_EvaluateDerivative(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Reset the plate in the initial state ( same as after create()).

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if all has been correctly done.

        Returns
        -------
        bool

        """
        return _Plate.Plate_Plate_IsDone(self, *args)

    def Load(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        PConst: Plate_PinpointConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        LXYZConst: Plate_LinearXYZConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        LScalarConst: Plate_LinearScalarConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        GTConst: Plate_GlobalTranslationConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        LConst: Plate_LineConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        PConst: Plate_PlaneConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        SCConst: Plate_SampledCurveConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        GtoCConst: Plate_GtoCConstraint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        FGtoCConst: Plate_FreeGtoCConstraint

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_Load(self, *args)

    def SetPolynomialPartOnly(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        PPOnly: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_SetPolynomialPartOnly(self, *args)

    def SolveTI(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ord: int,optional
        	default value is 4
        anisotropie: float,optional
        	default value is 1.0
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_SolveTI(self, *args)

    def UVBox(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        UMin: float
        UMax: float
        VMin: float
        VMax: float

        """
        return _Plate.Plate_Plate_UVBox(self, *args)

    def UVConstraints(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Seq: TColgp_SequenceOfXY

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_UVConstraints(self, *args)

    def destroy(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _Plate.Plate_Plate_destroy(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_Plate

# Register Plate_Plate in _Plate:
_Plate.Plate_Plate_swigregister(Plate_Plate)

class Plate_SampledCurveConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        SOPPC: Plate_SequenceOfPinpointConstraint
        n: int

        Returns
        -------
        None

        """
        _Plate.Plate_SampledCurveConstraint_swiginit(self, _Plate.new_Plate_SampledCurveConstraint(*args))

    def LXYZC(self, *args) -> "Plate_LinearXYZConstraint const &":
        r"""
        No available documentation.

        Returns
        -------
        Plate_LinearXYZConstraint

        """
        return _Plate.Plate_SampledCurveConstraint_LXYZC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Plate.delete_Plate_SampledCurveConstraint

# Register Plate_SampledCurveConstraint in _Plate:
_Plate.Plate_SampledCurveConstraint_swigregister(Plate_SampledCurveConstraint)

class Plate_HArray1OfPinpointConstraint(Plate_Array1OfPinpointConstraint, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _Plate.Plate_HArray1OfPinpointConstraint_swiginit(self, _Plate.new_Plate_HArray1OfPinpointConstraint(*args))

    def Array1(self) -> "Plate_Array1OfPinpointConstraint const &":
        return _Plate.Plate_HArray1OfPinpointConstraint_Array1(self)

    def ChangeArray1(self) -> "Plate_Array1OfPinpointConstraint &":
        return _Plate.Plate_HArray1OfPinpointConstraint_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_Plate_HArray1OfPinpointConstraint_DownCast(t)

    __swig_destroy__ = _Plate.delete_Plate_HArray1OfPinpointConstraint

# Register Plate_HArray1OfPinpointConstraint in _Plate:
_Plate.Plate_HArray1OfPinpointConstraint_swigregister(Plate_HArray1OfPinpointConstraint)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *
from OCC.Core.Message import *


class Plate_Array1OfPinpointConstraint:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> Plate_PinpointConstraint: ...
    def __setitem__(self, index: int, value: Plate_PinpointConstraint) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[Plate_PinpointConstraint]: ...
    def next(self) -> Plate_PinpointConstraint: ...
    __next__ = next
    def Init(self, theValue: Plate_PinpointConstraint) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> Plate_PinpointConstraint: ...
    def Last(self) -> Plate_PinpointConstraint: ...
    def Value(self, theIndex: int) -> Plate_PinpointConstraint: ...
    def SetValue(self, theIndex: int, theValue: Plate_PinpointConstraint) -> None: ...

class Plate_SequenceOfLinearScalarConstraint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Plate_LinearScalarConstraint: ...
    def Last(self) -> Plate_LinearScalarConstraint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Plate_LinearScalarConstraint) -> Plate_LinearScalarConstraint: ...
    def Prepend(self, theItem: Plate_LinearScalarConstraint) -> Plate_LinearScalarConstraint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Plate_LinearScalarConstraint: ...
    def SetValue(self, theIndex: int, theValue: Plate_LinearScalarConstraint) -> None: ...

class Plate_SequenceOfLinearXYZConstraint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Plate_LinearXYZConstraint: ...
    def Last(self) -> Plate_LinearXYZConstraint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Plate_LinearXYZConstraint) -> Plate_LinearXYZConstraint: ...
    def Prepend(self, theItem: Plate_LinearXYZConstraint) -> Plate_LinearXYZConstraint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Plate_LinearXYZConstraint: ...
    def SetValue(self, theIndex: int, theValue: Plate_LinearXYZConstraint) -> None: ...

class Plate_SequenceOfPinpointConstraint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Plate_PinpointConstraint: ...
    def Last(self) -> Plate_PinpointConstraint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Plate_PinpointConstraint) -> Plate_PinpointConstraint: ...
    def Prepend(self, theItem: Plate_PinpointConstraint) -> Plate_PinpointConstraint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Plate_PinpointConstraint: ...
    def SetValue(self, theIndex: int, theValue: Plate_PinpointConstraint) -> None: ...

class Plate_D1:
	@overload
	def __init__(self, du: gp_XYZ, dv: gp_XYZ) -> None: ...
	@overload
	def __init__(self, ref: Plate_D1) -> None: ...
	def DU(self) -> gp_XYZ: ...
	def DV(self) -> gp_XYZ: ...

class Plate_D2:
	@overload
	def __init__(self, duu: gp_XYZ, duv: gp_XYZ, dvv: gp_XYZ) -> None: ...
	@overload
	def __init__(self, ref: Plate_D2) -> None: ...

class Plate_D3:
	@overload
	def __init__(self, duuu: gp_XYZ, duuv: gp_XYZ, duvv: gp_XYZ, dvvv: gp_XYZ) -> None: ...
	@overload
	def __init__(self, ref: Plate_D3) -> None: ...

class Plate_FreeGtoCConstraint:
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, IncrementalLoad: Optional[float] = 1.0, orientation: Optional[int] = 0) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, D2S: Plate_D2, D2T: Plate_D2, IncrementalLoad: Optional[float] = 1.0, orientation: Optional[int] = 0) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, D2S: Plate_D2, D2T: Plate_D2, D3S: Plate_D3, D3T: Plate_D3, IncrementalLoad: Optional[float] = 1.0, orientation: Optional[int] = 0) -> None: ...
	def GetPPC(self, Index: int) -> Plate_PinpointConstraint: ...
	def LSC(self, Index: int) -> Plate_LinearScalarConstraint: ...
	def nb_LSC(self) -> int: ...
	def nb_PPC(self) -> int: ...

class Plate_GlobalTranslationConstraint:
	def __init__(self, SOfXY: TColgp_SequenceOfXY) -> None: ...
	def LXYZC(self) -> Plate_LinearXYZConstraint: ...

class Plate_GtoCConstraint:
	@overload
	def __init__(self, ref: Plate_GtoCConstraint) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, nP: gp_XYZ) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, D2S: Plate_D2, D2T: Plate_D2) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, D2S: Plate_D2, D2T: Plate_D2, nP: gp_XYZ) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, D2S: Plate_D2, D2T: Plate_D2, D3S: Plate_D3, D3T: Plate_D3) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, D1S: Plate_D1, D1T: Plate_D1, D2S: Plate_D2, D2T: Plate_D2, D3S: Plate_D3, D3T: Plate_D3, nP: gp_XYZ) -> None: ...
	def D1SurfInit(self) -> Plate_D1: ...
	def GetPPC(self, Index: int) -> Plate_PinpointConstraint: ...
	def nb_PPC(self) -> int: ...

class Plate_LineConstraint:
	def __init__(self, point2d: gp_XY, lin: gp_Lin, iu: Optional[int] = 0, iv: Optional[int] = 0) -> None: ...
	def LSC(self) -> Plate_LinearScalarConstraint: ...

class Plate_LinearScalarConstraint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePPC1: Plate_PinpointConstraint, theCoeff: gp_XYZ) -> None: ...
	@overload
	def __init__(self, thePPC: Plate_Array1OfPinpointConstraint, theCoeff: TColgp_Array1OfXYZ) -> None: ...
	@overload
	def __init__(self, thePPC: Plate_Array1OfPinpointConstraint, theCoeff: TColgp_Array2OfXYZ) -> None: ...
	@overload
	def __init__(self, ColLen: int, RowLen: int) -> None: ...
	def Coeff(self) -> TColgp_Array2OfXYZ: ...
	def GetPPC(self) -> Plate_Array1OfPinpointConstraint: ...
	def SetCoeff(self, Row: int, Col: int, Value: gp_XYZ) -> None: ...
	def SetPPC(self, Index: int, Value: Plate_PinpointConstraint) -> None: ...

class Plate_LinearXYZConstraint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePPC: Plate_Array1OfPinpointConstraint, theCoeff: TColStd_Array1OfReal) -> None: ...
	@overload
	def __init__(self, thePPC: Plate_Array1OfPinpointConstraint, theCoeff: TColStd_Array2OfReal) -> None: ...
	@overload
	def __init__(self, ColLen: int, RowLen: int) -> None: ...
	def Coeff(self) -> TColStd_Array2OfReal: ...
	def GetPPC(self) -> Plate_Array1OfPinpointConstraint: ...
	def SetCoeff(self, Row: int, Col: int, Value: float) -> None: ...
	def SetPPC(self, Index: int, Value: Plate_PinpointConstraint) -> None: ...

class Plate_PinpointConstraint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, point2d: gp_XY, ImposedValue: gp_XYZ, iu: Optional[int] = 0, iv: Optional[int] = 0) -> None: ...
	def Idu(self) -> int: ...
	def Idv(self) -> int: ...
	def Pnt2d(self) -> gp_XY: ...
	def Value(self) -> gp_XYZ: ...

class Plate_PlaneConstraint:
	def __init__(self, point2d: gp_XY, pln: gp_Pln, iu: Optional[int] = 0, iv: Optional[int] = 0) -> None: ...
	def LSC(self) -> Plate_LinearScalarConstraint: ...

class Plate_Plate:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Ref: Plate_Plate) -> None: ...
	def CoefPol(self, Coefs: TColgp_HArray2OfXYZ) -> None: ...
	def Continuity(self) -> int: ...
	def Copy(self, Ref: Plate_Plate) -> Plate_Plate: ...
	def Evaluate(self, point2d: gp_XY) -> gp_XYZ: ...
	def EvaluateDerivative(self, point2d: gp_XY, iu: int, iv: int) -> gp_XYZ: ...
	def Init(self) -> None: ...
	def IsDone(self) -> bool: ...
	@overload
	def Load(self, PConst: Plate_PinpointConstraint) -> None: ...
	@overload
	def Load(self, LXYZConst: Plate_LinearXYZConstraint) -> None: ...
	@overload
	def Load(self, LScalarConst: Plate_LinearScalarConstraint) -> None: ...
	@overload
	def Load(self, GTConst: Plate_GlobalTranslationConstraint) -> None: ...
	@overload
	def Load(self, LConst: Plate_LineConstraint) -> None: ...
	@overload
	def Load(self, PConst: Plate_PlaneConstraint) -> None: ...
	@overload
	def Load(self, SCConst: Plate_SampledCurveConstraint) -> None: ...
	@overload
	def Load(self, GtoCConst: Plate_GtoCConstraint) -> None: ...
	@overload
	def Load(self, FGtoCConst: Plate_FreeGtoCConstraint) -> None: ...
	def SetPolynomialPartOnly(self, PPOnly: Optional[bool] = True) -> None: ...
	def SolveTI(self, ord: Optional[int] = 4, anisotropie: Optional[float] = 1.0, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def UVBox(self) -> Tuple[float, float, float, float]: ...
	def UVConstraints(self, Seq: TColgp_SequenceOfXY) -> None: ...
	def destroy(self) -> None: ...

class Plate_SampledCurveConstraint:
	def __init__(self, SOPPC: Plate_SequenceOfPinpointConstraint, n: int) -> None: ...
	def LXYZC(self) -> Plate_LinearXYZConstraint: ...

# harray1 classes

class Plate_HArray1OfPinpointConstraint(Plate_Array1OfPinpointConstraint, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Plate_Array1OfPinpointConstraint: ...

# harray2 classes
# hsequence classes

